# Kentaro Fukumoto

rm(list=ls())

###############
# Gibbs sampler

# download Data.Code.zip at http://jgill.wustl.edu/BMSBSA2/
# unzip it. gibbs.exponential.s in the chapter01 folder.
source("gibbs.exponential.s")

plot(x,y)
mean(x)
quantile(x,c(0.025,0.975))

# another sampler
# 1 chain
x <- y <- array(dim=m)
x[1] <- y[1] <- 0.5 
set.seed(10012013)
for (j in 2:m)  {
  x.cand <- y.cand <- B+1
  while(x.cand > B){
    x.cand <- rexp(1,y[j-1])
  }
  x[j] <- x.cand 
  while(y.cand > B){
    y.cand <- rexp(1,x[j])
  }
  y[j] <- y.cand 
}

source("figure.r")

############################
# Metropolis sampler (p. 36)

bivariate.exponential <- function(x,y,L1,L2,L){
  exp(-(L1+L)*x -(L2+L)*y -L*max(x,y))
}

# setup
m<-5000
x <- y <- array(dim=m)
x[1] <- y[1] <- 0.5 
L1<-0.5
L2<-0.1
L<-0.01
B<-8

# sampling
set.seed(10022013)
source("metropolis.gill.r")
source("figure.r")
plot(x,type='l')
plot(y,type='l')
plot(x,y,type='l')
plot(x,y)

# not converge
B<-80
set.seed(10022014)
source("metropolis.gill.r")
plot(x,type='l')
plot(y,type='l')

# another sampler
B<-1
set.seed(10032013)
source("metropolis.fukumoto.r")
plot(x,type='l')
plot(y,type='l')

# not so good a starting point
x[1] <- y[1] <- 49 
set.seed(10042013)
source("metropolis.fukumoto.r")
plot(x,type='l')
plot(x[-1],type='l')

# consensus.s in the chapter03 folder
source("consensus.s")